@@ -11,9 +11,9 @@ use Exporter qw(import);
 use List::Util qw(first max);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-09'; # DATE
+our $DATE = '2022-01-21'; # DATE
 our $DIST = 'Perinci-Result-Format-Lite'; # DIST
-our $VERSION = '0.282'; # VERSION
+our $VERSION = '0.283'; # VERSION
 
 our @EXPORT_OK = qw(format);
 
@@ -379,6 +379,12 @@ sub __gen_table {
                     } @$row)."\n";
             } @$data
         );
+    } elsif ($format eq 'tsv') {
+        no warnings 'uninitialized';
+        join("", map { my $row = $_; join("\t", @$row)."\n" } @$data);
+    } elsif ($format eq 'ltsv') {
+        no warnings 'uninitialized';
+        join("", map { my $row = $_; join("\t", map { "$columns[$_]:$row->[$_]" } 0 .. $#{$row})."\n" } @$data);
     } elsif ($format eq 'html') {
         no warnings 'uninitialized';
         require HTML::Entities;
@@ -425,7 +431,7 @@ sub __gen_table {
 sub format {
     my ($res, $format, $is_naked, $cleanse) = @_;
 
-    if ($format =~ /\A(text|text-simple|text-pretty|csv|html)\z/) {
+    if ($format =~ /\A(text|text-simple|text-pretty|csv|tsv|ltsv|html)\z/) {
         $format = $format eq 'text' ?
             ((-t STDOUT) ? 'text-pretty' : 'text-simple') : $format;
         no warnings 'uninitialized';
@@ -545,7 +551,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.282 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2021-12-09.
+This document describes version 0.283 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2022-01-21.
 
 =head1 SYNOPSIS
 
@@ -618,7 +624,7 @@ beyond that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2022, 2021, 2020, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
